<?php
/*******************************************************************************
Common function to create a new entry in the IP Tracking table
/******************************************************************************/
function AddIpEntry($db_table) {
    $insert_sql_data =
       " count = '1', " .
       " ip_number = INET_ATON( '" . $_SERVER['REMOTE_ADDR'] . "' ), " .
       " last_date = now() " 
      ;
       
    tep_db_query("insert into " . $db_table . " set " . $insert_sql_data);
} 

/*******************************************************************************
Check to see if this customer has created an account in a certain period of time.
Returns true if they have.
/******************************************************************************/
function CheckCreateAccountHP($all_fields) { 
    $cust = $all_fields['firstname'] . ' ' . $all_fields['lastname'];
    
    if (! filter_var($_SERVER['REMOTE_ADDR'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV4)) {
        return false; //either an IPV6 or invalid IP so ignore
    }    
     
    $ip_array = explode(',', MODULE_HEADER_TAGS_HONEYPOT_EXCLUDE_IPS);
    $ip_array = array_map('trim', $ip_array);
    if (in_array($_SERVER['REMOTE_ADDR'], $ip_array)) {
        return false;         //good IP so allow
    }
    
    if (isset($all_fields['hp_coupon_code']) && tep_not_null($all_fields['hp_coupon_code'])) {
        WriteToLog(sprintf(TEXT_PAGE_VIOLATION_HONEYPOT, $_SERVER['REMOTE_ADDR'])); 
        return true;
    }        
    
    if (CheckReferer()) {  //known bad IP so block  
        WriteToLog(TEXT_CHECK_REFERER_FAILED);   
        return true;
    }    
    
    if (CheckTimeToSubmit()) {  
        WriteToLog(TEXT_CHECK_TIME_TO_SUBMIT);   
        return true;
    }      
            
    if (CheckBlackLists()) {  //known bad IP so block  
        WriteToLog(TEXT_CREATE_ACCOUNT_IPLIST);   
        return true;
    }    
      	
    if (MODULE_HEADER_TAGS_HONEYPOT_BLOCK_LETTERS_IN_PHONE == 'True') {
        $str = $all_fields['telephone'] . $all_fields['fax']; 
        for ($i = 0; $i < strlen($str); $i++) {
            if (ctype_alpha($str[$i])) {   
                WriteToLog(TEXT_CREATE_ACCOUNT_LETTERS_IN_PHONE);   
                return true;  //block but could be a mistake
            }
        }	  
    }	
   
    if (MODULE_HEADER_TAGS_HONEYPOT_BLOCK_NUMBERS_IN_NAME == 'True') {
        //if (preg_match("/[^-\p{L}.\' ]\/u/", $cust)) {   //unicode check - it works but may be too restrictive
        if (preg_match("/\d/", $cust)) {   
            WriteToLog(TEXT_CREATE_ACCOUNT_NUMBERS_IN_NAME);        
            return true;      //block but could be a mistake
        }    
    }

    if (MODULE_HEADER_TAGS_HONEYPOT_BLOCK_NUMBERS_IN_SUBURB == 'True') {
        if (preg_match("/\d/", $all_fields['suburb'])) {   
            WriteToLog(TEXT_CREATE_ACCOUNT_NUMBERS_IN_SUBURB);        
            return true;     
        }    
    }
   
    if (tep_not_null(MODULE_HEADER_TAGS_HONEYPOT_CREATE_ACCOUNT_NAME_LENGTH_FIRST)) {
        if (str_word_count($all_fields['firstname']) > MODULE_HEADER_TAGS_HONEYPOT_CREATE_ACCOUNT_NAME_LENGTH_FIRST) {
            WriteToLog(TEXT_CREATE_ACCOUNT_LENGTH_FIRSTNAME);
            return true;      //block but could be a mistake
        }			
    }	
          
    if (tep_not_null(MODULE_HEADER_TAGS_HONEYPOT_CREATE_ACCOUNT_NAME_LENGTH_LAST)) {
        if (str_word_count($all_fields['lastname']) > MODULE_HEADER_TAGS_HONEYPOT_CREATE_ACCOUNT_NAME_LENGTH_LAST) {
            WriteToLog(TEXT_CREATE_ACCOUNT_LENGTH_LASTNAME);
            return true;      //block but could be a mistake
        }			
    }	
   
    if (CheckBadWords($all_fields)) {
        WriteToLog(TEXT_CREATE_ACCOUNT_BAD_WORDS);
        return true;          //block but could be a mistake
    } 
       
    if (CheckCaptcha()) {
        WriteToLog(TEXT_CREATE_ACCOUNT_CAPTCHA); 
        return true;          //block but could be a mistake
    }   
       
    if (CheckPostalCode($all_fields['postcode'], $all_fields['country'])) {
        WriteToLog(TEXT_CREATE_ACCOUNT_INVALID_POSTAL_CODE); 
        return true;           
    }      
        
    if (CheckCountryState($all_fields['state'], $all_fields['country'])) {
       WriteToLog(TEXT_CREATE_ACCOUNT_INVALID_COUNTRY_STATE); 
       return true;   
    }        
       
    if (CheckHTMLTags($all_fields)) {
        WriteToLog(TEXT_CREATE_ACCOUNT_HAS_HTML);
        return true;                   
    } 
       
    $db_table = 'honeypot_track'; 
    if (CreateDatabaseTable($db_table)) {         

        $db_query = tep_db_query("select count, last_date from " . $db_table . " where ip_number = INET_ATON( '" . $_SERVER['REMOTE_ADDR'] . "' )");
        
        if (tep_db_num_rows($db_query)) {
         
            $db = tep_db_fetch_array($db_query); 
            
            if ($db['count'] == MODULE_HEADER_TAGS_HONEYPOT_CREATE_ACCOUNT_CHECK_COUNT) {
                WriteToLog(sprintf(TEXT_CREATE_ACCOUNT_CHECK_COUNT, $cust));                
                return true; //block it due to too many accounts
            }    
            
            $past_time = strtotime($db['last_date']);
            $diff = round(abs(time() - $past_time) / 60, 0, PHP_ROUND_HALF_UP);  //results in minutes
     
            if ($diff < MODULE_HEADER_TAGS_HONEYPOT_CREATE_ACCOUNT_CHECK_PERIOD) {
               WriteToLog(sprintf(TEXT_CREATE_ACCOUNT_CHECK_PERIOD, $cust)); 
               return true; //block it
            }              
        } else { //an entry for this IP doesn't exist so add one
            if (defined('MODULE_HEADER_TAGS_HONEYPOT_VERIFY_TIME_TO_SUBMIT') && tep_not_null(MODULE_HEADER_TAGS_HONEYPOT_VERIFY_TIME_TO_SUBMIT)) {
                if (! tep_session_is_registered('time_check')) {
                    $time_check = time(); 
                    tep_session_register('time_check');   
                }    
            }
            
            WriteToLog(sprintf(TEXT_CREATE_ACCOUNT_NEW_ACCOUNT, $cust)); 
        }   
    }    

    return false; 
}

function CheckBadWords($data) {
    if (tep_not_null(MODULE_HEADER_TAGS_HONEYPOT_BAD_WORDS)) {
        $string = $data;
        if (is_array($data)) {
            $string = '';
            foreach ($data as $item) {
                $string .= $item;
            } 
        } 
        
        $words = array_map('trim', explode(',', MODULE_HEADER_TAGS_HONEYPOT_BAD_WORDS));
        foreach ($words as $word) {
            if (stripos($string, $word) !== FALSE) {
                return true;      
            } 
        } 
    }
     
    return false;
} 
 
function CheckBlackLists() {
    if (MODULE_HEADER_TAGS_HONEYPOT_USE_IPLIST == 'IPList' || MODULE_HEADER_TAGS_HONEYPOT_USE_IPLIST == 'Both') {
        if (CheckMyIP()) {
            return true;
        }  
    }    
    
    if (MODULE_HEADER_TAGS_HONEYPOT_USE_IPLIST == 'Tor' || MODULE_HEADER_TAGS_HONEYPOT_USE_IPLIST == 'Both') {
        if (CheckTOR()) {
            return true;
        }    
    }
    return false;
}

function CheckCountryState($state, $country) {
    if (MODULE_HEADER_TAGS_HONEYPOT_VERIFY_STATE_COUNTRY_MATCH == 'True') {
        $has_zone_query = tep_db_query("SELECT 1 FROM zones WHERE zone_country_id = " . (int)$country);
        if (tep_db_num_rows($has_zone_query)) {
            $db_query = tep_db_query("select 1 from zones where zone_country_id = " . (int)$country . " and (zone_code = '" . tep_db_input($state) . "' or zone_name = '" . tep_db_input($state) . "')");
            return !tep_db_num_rows($db_query);
        }
    }
    return false;    
}
 
function CheckHTMLTags($all_fields) {
    foreach ($all_fields as $item) {
        if($item != strip_tags($item)) {
            return true; // contains HTML
        }
    } 
    return false;
}

function CheckCaptcha() {
    if (MODULE_HEADER_TAGS_HONEYPOT_CAPTCHA != 'None') {
        if (empty($_POST['security_answer']) || $_POST['security_answer'] != $_SESSION['security_question']) {
            return true;
        }	
    } 
    return false;
}    
 
function CheckMyIP() {  
    if (MODULE_HEADER_TAGS_HONEYPOT_USE_IPLIST == 'True') {
        $path = DIR_FS_CATALOG . 'includes/honeypot/iplist.txt';
        
        if (file_exists($path)) {
            $iplist = @file($path, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
            
            if (is_array($iplist) && in_array($_SERVER['REMOTE_ADDR'], $iplist)) {
                return true;
            } 
        } 
    }
    return false;    
} 
 
function CheckPostalCode($postcode, $country) {
    if (MODULE_HEADER_TAGS_HONEYPOT_VERIFY_POSTAL_CODE != 'Ignore') {
        if (MODULE_HEADER_TAGS_HONEYPOT_VERIFY_POSTAL_CODE == 'Blank' || MODULE_HEADER_TAGS_HONEYPOT_VERIFY_POSTAL_CODE == 'Both') {
            if (empty($postcode)) return false; //post code is blank and the option says to allow this
        }               

        if (MODULE_HEADER_TAGS_HONEYPOT_VERIFY_POSTAL_CODE == 'Numbers' || MODULE_HEADER_TAGS_HONEYPOT_VERIFY_POSTAL_CODE == 'Both') {
            if (empty($postcode)) return true; //post code doesn't contain a number so fail

            $ZIPREG=array(
             "AD"=>"^AD\d{3}?$",
             "AM"=>"^(37)?\d{4}?$",
             "AR"=>"^([A-HJ-NP-Z])?\d{4}([A-Z]{3})?$",
             "AS"=>"^96799?$",
             "AT"=>"^\d{4}?$",
             "AU"=>"^(0[289][0-9]{2})|([1345689][0-9]{3})|(2[0-8][0-9]{2})|(290[0-9])|(291[0-4])|(7[0-4][0-9]{2})|(7[8-9][0-9]{2})?$",
             "AX"=>"^22\d{3}?$",
             "AZ"=>"^\d{4}?$",
             "BA"=>"^\d{5}?$",
             "BB"=>"^(BB\d{5})?$",
             "BD"=>"^\d{4}?$",
             "BE"=>"^[1-9]{1}[0-9]{3}?$",
             "BG"=>"^\d{4}?$",
             "BH"=>"^((1[0-2]|[2-9])\d{2})?$",
             "BM"=>"^[A-Z]{2}[ ]?[A-Z0-9]{2}?$",
             "BN"=>"^[A-Z]{2}[ ]?\d{4}?$",
             "BR"=>"^\d{5}[\-]?\d{3}?$",
             "BY"=>"^\d{6}?$",
             "CA"=>"^([ABCEGHJKLMNPRSTVXY]\d[ABCEGHJKLMNPRSTVWXYZ])\ {0,1}(\d[ABCEGHJKLMNPRSTVWXYZ]\d)?$",
             "CC"=>"^6799?$",
             "CH"=>"^\d{4}?$",
             "CK"=>"^\d{4}?$",
             "CL"=>"^\d{7}?$",
             "CN"=>"^\d{6}?$",
             "CR"=>"^\d{4,5}|\d{3}-\d{4}?$",
             "CS"=>"^\d{5}?$",
             "CV"=>"^\d{4}?$",
             "CX"=>"^6798?$",
             "CY"=>"^\d{4}?$",
             "CZ"=>"^\d{3}[ ]?\d{2}?$",
             "DK"=>"^([D-d][K-k])?( |-)?[1-9]{1}[0-9]{3}?$",
             "DO"=>"^\d{5}?$",
             "DZ"=>"^\d{5}?$",
             "EC"=>"^([A-Z]\d{4}[A-Z]|(?:[A-Z]{2})?\d{6})?$",
             "EE"=>"^\d{5}?$",
             "EG"=>"^\d{5}?$",
             "ES"=>"^([1-9]{2}|[0-9][1-9]|[1-9][0-9])[0-9]{3}?$",
             "ET"=>"^\d{4}?$",
             "FI"=>"^\d{5}?$",
             "FK"=>"^FIQQ 1ZZ?$",
             "FM"=>"^(9694[1-4])([ \-]\d{4})?$",
             "FO"=>"^\d{3}?$",
             "FR"=>"^(F-)?((2[A|B])|[0-9]{2})[0-9]{3}?$",
             "GB"=>"^(GIR|[A-Z]\d[A-Z\d]??|[A-Z]{2}\d[A-Z\d]??)[ ]??(\d[A-Z]{2})?$",
             "GE"=>"^\d{4}?$",
             "GF"=>"^9[78]3\d{2}?$",
             "GG"=>"^GY\d[\dA-Z]?[ ]?\d[ABD-HJLN-UW-Z]{2}?$",
             "GL"=>"^39\d{2}?$",
             "GN"=>"^\d{3}?$",
             "GP"=>"^9[78][01]\d{2}?$",
             "GR"=>"^\d{3}[ ]?\d{2}?$",
             "GS"=>"^SIQQ 1ZZ?$",
             "GT"=>"^\d{5}?$",
             "GU"=>"^969[123]\d([ \-]\d{4})?$",
             "GW"=>"^\d{4}?$",
             "HM"=>"^\d{4}?$",
             "HN"=>"^(?:\d{5})?$",
             "HR"=>"^\d{5}?$",
             "HT"=>"^\d{4}?$",
             "HU"=>"^\d{4}?$",
             "ID"=>"^\d{5}?$",
             "IL"=>"^\d{5}?$",
             "IM"=>"^IM\d[\dA-Z]?[ ]?\d[ABD-HJLN-UW-Z]{2}?$",
             "IN"=>"^\d{6}?$",
             "IO"=>"^BBND 1ZZ?$",
             "IQ"=>"^\d{5}?$",
             "IS"=>"^\d{3}?$",
             "IT"=>"^(V-|I-)?[0-9]{5}?$",
             "JE"=>"^JE\d[\dA-Z]?[ ]?\d[ABD-HJLN-UW-Z]{2}?$",
             "JO"=>"^\d{5}?$",
             "JP"=>"^\d{3}-\d{4}?$",
             "KE"=>"^\d{5}?$",
             "KG"=>"^\d{6}?$",
             "KH"=>"^\d{5}?$",
             "KR"=>"^\d{3}[\-]\d{3}?$",
             "KW"=>"^\d{5}?$",
             "KZ"=>"^\d{6}?$",
             "LA"=>"^\d{5}?$",
             "LB"=>"^(\d{4}([ ]?\d{4})?)?$",
             "LI"=>"^(948[5-9])|(949[0-7])?$",
             "LK"=>"^\d{5}?$",
             "LR"=>"^\d{4}?$",
             "LS"=>"^\d{3}?$",
             "LT"=>"^\d{5}?$",
             "LU"=>"^\d{4}?$",
             "LV"=>"^\d{4}?$",
             "MA"=>"^\d{5}?$",
             "MC"=>"^980\d{2}?$",
             "MD"=>"^\d{4}?$",
             "ME"=>"^8\d{4}?$",
             "MG"=>"^\d{3}?$",
             "MH"=>"^969[67]\d([ \-]\d{4})?$",
             "MK"=>"^\d{4}?$",
             "MN"=>"^\d{6}?$",
             "MP"=>"^9695[012]([ \-]\d{4})?$",
             "MQ"=>"^9[78]2\d{2}?$",
             "MT"=>"^[A-Z]{3}[ ]?\d{2,4}?$",
             "MU"=>"^(\d{3}[A-Z]{2}\d{3})?$",
             "MV"=>"^\d{5}?$",
             "MX"=>"^\d{5}?$",
             "MY"=>"^\d{5}?$",
             "NC"=>"^988\d{2}?$",
             "NE"=>"^\d{4}?$",
             "NF"=>"^2899?$",
             "NG"=>"^(\d{6})?$",
             "NI"=>"^((\d{4}-)?\d{3}-\d{3}(-\d{1})?)?$",
             "NL"=>"^[1-9][0-9]{3}\s?([a-zA-Z]{2})?$",
             "NO"=>"^\d{4}?$",
             "NP"=>"^\d{5}?$",
             "NZ"=>"^\d{4}?$",
             "OM"=>"^(PC )?\d{3}?$",
             "PF"=>"^987\d{2}?$",
             "PG"=>"^\d{3}?$",
             "PH"=>"^\d{4}?$",
             "PK"=>"^\d{5}?$",
             "PL"=>"^\d{2}-\d{3}?$",
             "PM"=>"^9[78]5\d{2}?$",
             "PN"=>"^PCRN 1ZZ?$",
             "PR"=>"^00[679]\d{2}([ \-]\d{4})?$",
             "PT"=>"^\d{4}([\-]\d{3})?$",
             "PW"=>"^96940?$",
             "PY"=>"^\d{4}?$",
             "RE"=>"^9[78]4\d{2}?$",
             "RO"=>"^\d{6}?$",
             "RS"=>"^\d{6}?$",
             "RU"=>"^\d{6}?$",
             "SA"=>"^\d{5}?$",
             "SE"=>"^(s-|S-){0,1}[0-9]{3}\s?[0-9]{2}?$",
             "SG"=>"^\d{6}?$",
             "SH"=>"^(ASCN|STHL) 1ZZ?$",
             "SI"=>"^\d{4}?$",
             "SJ"=>"^\d{4}?$",
             "SK"=>"^\d{3}[ ]?\d{2}?$",
             "SM"=>"^4789\d?$",
             "SN"=>"^\d{5}?$",
             "SO"=>"^\d{5}?$",
             "SZ"=>"^[HLMS]\d{3}?$",
             "TC"=>"^TKCA 1ZZ?$",
             "TH"=>"^\d{5}?$",
             "TJ"=>"^\d{6}?$",
             "TM"=>"^\d{6}?$",
             "TN"=>"^\d{4}?$",
             "TR"=>"^\d{5}?$",
             "TW"=>"^\d{3}(\d{2})?$",
             "UA"=>"^\d{5}?$",
             "US"=>"^\d{5}([\-]?\d{4})?$",
             "UY"=>"^\d{5}?$",
             "UZ"=>"^\d{6}?$",
             "VA"=>"^00120?$",
             "VE"=>"^\d{4}?$",
             "VI"=>"^008(([0-4]\d)|(5[01]))([ \-]\d{4})?$",
             "WF"=>"^986\d{2}?$",
             "XK"=>"^\d{5}?$",
             "YT"=>"^976\d{2}?$",
             "YU"=>"^\d{5}?$",
             "ZA"=>"^\d{4}?$",
             "ZM"=>"^\d{5}?$"
            );
            $db_query = tep_db_query("select countries_iso_code_2 from countries where countries_id = '" . tep_db_input($country) . "'");
            if (tep_db_num_rows($db_query)) {
                $db = tep_db_fetch_array($db_query);
                if (isset($ZIPREG[$db['countries_iso_code_2']]) && ! preg_match("/".$ZIPREG[$db['countries_iso_code_2']]."/i",$postcode)) {
                    return true;             
                }  
            }
                       
            //Above country verification failed so just make sure the postal code has at least one number
            $has_numbers = false;
            for ($i = 0; $i < strlen($postcode); ++$i) {
                if (ctype_digit($postcode[$i])) {
                    $has_numbers = true; 
                }    
            }   
            if (! $has_numbers) return true;            
        }  
    }
    return false;    
}
 
function CheckReferer() {
    if (MODULE_HEADER_TAGS_HONEYPOT_VERIFY_REFERER_MATCH == 'True') {
        if (isset($_SERVER['HTTP_REFERER']) && array_key_exists($_SERVER['HTTP_REFERER'], $_SERVER) && stripos($_SERVER['HTTP_REFERER'], $HTTPS_SERVER) !== FALSE) {
            return true;
        }    
    }
    return false;    
}

function CheckTimeToSubmit() {
    if (defined('MODULE_HEADER_TAGS_HONEYPOT_VERIFY_TIME_TO_SUBMIT') && tep_not_null(MODULE_HEADER_TAGS_HONEYPOT_VERIFY_TIME_TO_SUBMIT)) {
        if (isset($_SESSION['time_check'])) {
            //$diff = ((time() - $time_check) / 3660) * 1000;               
            $diff = ((time() - $_SESSION['time_check']) / 3660) * 1000;               
            
            if ($diff < MODULE_HEADER_TAGS_HONEYPOT_VERIFY_TIME_TO_SUBMIT) {
                $time_check = time(); //keep active in case script continues
                return true;
            } else {
                unset($_SESSION['time_check']);
            }              
        }
    }
    
    return false;    
} 
 
function CheckTOR() {
    $ips = file("https://check.torproject.org/cgi-bin/TorBulkExitList.py?ip=1.1.1.1", FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
    if ($ips) {
        foreach ($ips as $ip) {
            if (strpos($ip, '#') !== FALSE) continue;
            if (strpos($ip, $_SERVER['REMOTE_ADDR']) !== FALSE) {
                return true;
            } 
        } 
    }
    return false;
}  

function CreateDatabaseTable($db_table) {
    $db_query = tep_db_query("show tables from `" . DB_DATABASE . "` like '" . $db_table . "'");
     
    if (! tep_db_num_rows($db_query)) {
        tep_db_query("CREATE TABLE IF NOT EXISTS `" . $db_table . "` (ip_number INT( 64 ) UNSIGNED NOT NULL,
                                                                    count int (11) DEFAULT 0,
                                                                    last_date datetime NOT NULL,
                                                                    PRIMARY KEY(ip_number) )");
    
        if (! tep_db_query("show tables from `" . DB_DATABASE . "` like '" . $db_table . "'")) {
            return false;  //database creation failed - shop owner should be notified
        } 
    }
    return true;
}

/*********************************************
Get the name used for displaying messages on a
page with a form. It may not match the actual
name of the form.
*********************************************/
function GetFormName($page_name) {
    switch (true) {
        case $page_name == 'contact_us.php': return 'contact';
        case $page_name == 'tell_a_friend.php' : return 'friend';   
        case $page_name == 'customer_testimonials_write.php' : return 'testimonials';        
    }
    
    $page_parts = explode('.', $page_name);  //remove the extension   
    return $page_parts[0]; //assumes form name is used to show messages
} 
 
function InvalidText($enquiry) { 
    if (MODULE_HEADER_TAGS_HONEYPOT_ALLOW_EMAIL == 'False') {
        if (preg_match("/([a-zA-Z0-9._-]+@[a-zA-Z0-9._-]+\.[a-zA-Z0-9._-]+)/i", $enquiry)) {
           WriteToLog(TEXT_EMAIL_ADDRESSES_NOT_ALLOWED);
           
           if (MODULE_HEADER_TAGS_HONEYPOT_ALLOW_EMAIL_MSG == 'True') {
               return TEXT_EMAIL_ADDRESSES_NOT_ALLOWED;
           } 
           return 'failed';      
        } 
    }
    
    if (MODULE_HEADER_TAGS_HONEYPOT_ALLOW_URLS == 'False') {     
 
        $match_found = false;
        if (! ($match_found = preg_match("/(\b(((https?|ftp|file|[-A-Z0-9]|):\/\/)|www[.]))/i", $enquiry))) {  
            if (! ($match_found = preg_match("/(\b(((https?|ftp|file|):\/\/)|www[.])[-A-Z0-9+&@#\/%?=~_|!:,.;]*[-A-Z0-9+&@#\/%=~_|])/i", $enquiry))) {
                $match_found = preg_match("/([a-zA-Z0-9])(\.)([a-zA-Z0-9])/i", $enquiry);
            }   
        }    
    
        if ($match_found) {

           WriteToLog(TEXT_URLS_NOT_ALLOWED);

           if (MODULE_HEADER_TAGS_HONEYPOT_ALLOW_URLS_MSG == 'True') {
               return TEXT_URLS_NOT_ALLOWED;
           } 
           return 'failed';      
        }
    }
    
    if (CheckBadWords($enquiry)) {
        WriteToLog(TEXT_CREATE_ACCOUNT_BAD_WORDS);
        return 'failed'; 
    }        
    
    if (empty($enquiry)) {
        WriteToLog(TEXT_EMAIL_IS_EMPTY);
        return TEXT_EMAIL_IS_EMPTY_MSG;
    }        

    return 'good';
}    

/*******************************************************************************
Block the current IP from the site due to too many violations
/******************************************************************************/
function WriteToHtAccess() {
    $htaccessfile = '';
    $separator = ((substr(DIR_FS_CATALOG, -1) != '/') ? '/' : '');
    $htaccessfile = DIR_FS_CATALOG . $separator . '.htaccess';
    
    if ($htaccessfile && file_exists($htaccessfile)) {
        $htaccessArray = file($htaccessfile);
        $htaccessArray[] = 'deny from ' . $_SERVER['REMOTE_ADDR'] . PHP_EOL;
        $fp = fopen($htaccessfile, "w" );
        if ($fp) {
            if (flock($fp, LOCK_EX)) {
                foreach ($htaccessArray as $line) {
                   fputs($fp, $line);                   
                }
                fflush($fp);    // release lock
                flock($fp, LOCK_UN); 
            }                

            fclose($fp);
        }        
    }   
}
    
/*******************************************************************************
Log the violations and block the IP if excessive
/******************************************************************************/    
function WriteToLog($str, $update_cnt = true) {
     
    $db_table = 'honeypot_track'; 
    $table_found =  CreateDatabaseTable($db_table);
    
    if (! $table_found) { //the database creating failed so notify the shop owner 
        $text = TEXT_DATABASE_FAILURE;
        if (MODULE_HEADER_TAGS_HONEYPOT_LOG == 'File' || MODULE_HEADER_TAGS_HONEYPOT_LOG == 'Both') {         
            $logfile = 'includes/HoneyPot_log';
            clearstatcache(true, $logfile);
            error_log($text , 3, $logfile);
        }
        
        if (MODULE_HEADER_TAGS_HONEYPOT_LOG == 'EMail' || MODULE_HEADER_TAGS_HONEYPOT_LOG == 'Both') {         
            error_log($text, 1, STORE_OWNER_EMAIL_ADDRESS);
        }
    }     
    
    if ($update_cnt && $table_found)  {
        $db_query = tep_db_query("select count from " . $db_table . " where ip_number = INET_ATON( '" . $_SERVER['REMOTE_ADDR'] . "' )");
        if (tep_db_num_rows($db_query)) {
            tep_db_query("update " . $db_table . " set count = count+1, last_date = now() where ip_number = INET_ATON( '" . $_SERVER['REMOTE_ADDR'] . "')");
        } else {
            AddIpEntry($db_table);
        }          
    }

    if (MODULE_HEADER_TAGS_HONEYPOT_BLOCK_IP_AUTOMATICALLY > 0) {     
        if ($table_found) { 
            $db_query = tep_db_query("select count from " . $db_table . " where ip_number = INET_ATON( '" . $_SERVER['REMOTE_ADDR'] . "' )");
            if (tep_db_num_rows($db_query)) {
                $db = tep_db_fetch_array($db_query);
                if ($db['count'] > MODULE_HEADER_TAGS_HONEYPOT_BLOCK_IP_AUTOMATICALLY) { 
                    $str = TEXT_IP_PERMANENTLY_BLOCKED;
                    
                    $doWrite = true;
                    
                    $good_ips = explode(',', MODULE_HEADER_TAGS_HONEYPOT_EXCLUDE_IPS);
                    $good_ips = array_map(function($x){
                      return trim($x);
                    }, $good_ips); 
                    if (in_array($ip, $good_ips)) {
                        $doWrite = false;
                    }
                    if ($doWrite) {
                        WriteToHtAccess();
                    }
                } 
            } 
        }
    }
    
    if (MODULE_HEADER_TAGS_HONEYPOT_LOG !== 'None') {
        $text = $_SERVER['REMOTE_ADDR'] . ' ' . @date('m-d-Y') . ': ' . $str;
        
        $db_query = tep_db_query("select count from " . $db_table . " where ip_number = INET_ATON( '" . $_SERVER['REMOTE_ADDR'] . "' )");
        if (tep_db_num_rows($db_query)) {
            $db = tep_db_fetch_array($db_query);
            $text .= sprintf(TEXT_HAS_TTL_VIOLATIONS, $db['count']);
        } 
        
        $text .= "\n";
        
        if (MODULE_HEADER_TAGS_HONEYPOT_LOG == 'File' || MODULE_HEADER_TAGS_HONEYPOT_LOG == 'Both') {         
            $logfile = 'includes/HoneyPot_log';
            clearstatcache(true, $logfile);
            if (file_exists('includes/HoneyPot_log') && filesize($logfile) > 50000) {
                rename($logfile, $logfile . '_' . @date('m-d-Y'));
            } 
            error_log($text , 3, $logfile);
        }
        
        if (MODULE_HEADER_TAGS_HONEYPOT_LOG == 'EMail' || MODULE_HEADER_TAGS_HONEYPOT_LOG == 'Both') {         
            error_log($text, 1, STORE_OWNER_EMAIL_ADDRESS);
        }
    }
} 
